Index: webkit/glue/resource_loader_bridge.h |
diff --git a/webkit/glue/resource_loader_bridge.h b/webkit/glue/resource_loader_bridge.h |
index dcc86f4a5a6713baeea637967fc5ce9846fb504f..9872b8418d46183527a9eeda368a61e362f0047e 100644 |
--- a/webkit/glue/resource_loader_bridge.h |
+++ b/webkit/glue/resource_loader_bridge.h |
@@ -51,8 +51,11 @@ struct ResourceLoadTimingInfo { |
ResourceLoadTimingInfo(); |
~ResourceLoadTimingInfo(); |
- // All the values in this struct are given as offsets in milliseconds wrt |
- // this base time. |
+ // All the values in this struct are given as offsets in ticks wrt |
+ // this base tick count. |
+ int64 base_ticks; |
pfeldman
2011/08/09 18:15:22
To clarify: you only need this to be able to compa
James Simonsen
2011/08/09 18:31:51
Oops. In my haste, I uploaded a slightly older bra
|
+ |
+ // The value of Time::Now() when base_ticks was set. |
base::Time base_time; |
// The time that proxy processing started. For requests with no proxy phase, |